@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtwidgets_python.h>
 #include <pyside2_qtgui_python.h>
@@ -63,55 +57,60 @@
 #include <qsvgwidget.h>
 #include <qsvgrenderer.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QSVGGENERATOR_IDX                                        1
-#define SBK_QGRAPHICSSVGITEM_IDX                                     0
-#define SBK_QSVGRENDERER_IDX                                         2
-#define SBK_QSVGWIDGET_IDX                                           3
-#define SBK_QtSvg_IDX_COUNT                                          4
-
+enum : int {
+    SBK_QGRAPHICSSVGITEM_IDX                                 = 0,
+    SBK_QSVGGENERATOR_IDX                                    = 1,
+    SBK_QSVGRENDERER_IDX                                     = 2,
+    SBK_QSVGWIDGET_IDX                                       = 3,
+    SBK_QtSvg_IDX_COUNT                                      = 4
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtSvgTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtSvgModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtSvgTypeConverters;
 
 // Converter indices
-#define SBK_QTSVG_QLIST_QGRAPHICSITEMPTR_IDX                         0 // QList<QGraphicsItem* >
-#define SBK_QTSVG_QLIST_QGRAPHICSTRANSFORMPTR_IDX                    1 // const QList<QGraphicsTransform* > &
-#define SBK_QTSVG_QLIST_QOBJECTPTR_IDX                               2 // const QList<QObject* > &
-#define SBK_QTSVG_QLIST_QBYTEARRAY_IDX                               3 // QList<QByteArray >
-#define SBK_QTSVG_QLIST_QACTIONPTR_IDX                               4 // QList<QAction* >
-#define SBK_QTSVG_QLIST_QVARIANT_IDX                                 5 // QList<QVariant >
-#define SBK_QTSVG_QLIST_QSTRING_IDX                                  6 // QList<QString >
-#define SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                          7 // QMap<QString,QVariant >
-#define SBK_QtSvg_CONVERTERS_IDX_COUNT                               8
-
+enum : int {
+    SBK_QTSVG_QLIST_QGRAPHICSITEMPTR_IDX                     = 0, // QList<QGraphicsItem* >
+    SBK_QTSVG_QLIST_QGRAPHICSTRANSFORMPTR_IDX                = 1, // const QList<QGraphicsTransform* > &
+    SBK_QTSVG_QLIST_QOBJECTPTR_IDX                           = 2, // const QList<QObject* > &
+    SBK_QTSVG_QLIST_QBYTEARRAY_IDX                           = 3, // QList<QByteArray >
+    SBK_QTSVG_QLIST_QACTIONPTR_IDX                           = 4, // QList<QAction* >
+    SBK_QTSVG_QLIST_QVARIANT_IDX                             = 5, // QList<QVariant >
+    SBK_QTSVG_QLIST_QSTRING_IDX                              = 6, // QList<QString >
+    SBK_QTSVG_QMAP_QSTRING_QVARIANT_IDX                      = 7, // QMap<QString,QVariant >
+    SBK_QtSvg_CONVERTERS_IDX_COUNT                           = 8
+};
 // Macros for type check
 
 namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
-template<> inline PyTypeObject* SbkType< ::QSvgGenerator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGGENERATOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
+template<> inline PyTypeObject* SbkType< ::QSvgGenerator >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGGENERATOR_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSvgRenderer >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGRENDERER_IDX]); }
 template<> inline PyTypeObject* SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject*>(SbkPySide2_QtSvgTypes[SBK_QSVGWIDGET_IDX]); }
 
