@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtwidgets_python.h>
 #include <pyside2_qtgui_python.h>
@@ -61,41 +55,46 @@
 // Binded library includes
 #include <quiloader.h>
 // Conversion Includes - Primitive Types
-#include <QStringList>
-#include <QString>
-#include <signalmanager.h>
 #include <qabstractitemmodel.h>
+#include <QString>
+#include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QSet>
-#include <QList>
-#include <QMultiMap>
-#include <QMap>
+#include <pysideqflags.h>
 #include <QLinkedList>
+#include <QList>
+#include <QMap>
+#include <QMultiMap>
+#include <QPair>
+#include <QQueue>
+#include <QSet>
 #include <QStack>
 #include <QVector>
-#include <QQueue>
-#include <QPair>
-#include <pysideqflags.h>
 
 // Type indices
-#define SBK_QUILOADER_IDX                                            0
-#define SBK_QtUiTools_IDX_COUNT                                      1
-
+enum : int {
+    SBK_QUILOADER_IDX                                        = 0,
+    SBK_QtUiTools_IDX_COUNT                                  = 1
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtUiToolsTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtUiToolsModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtUiToolsTypeConverters;
 
 // Converter indices
-#define SBK_QTUITOOLS_QLIST_QOBJECTPTR_IDX                           0 // const QList<QObject* > &
-#define SBK_QTUITOOLS_QLIST_QBYTEARRAY_IDX                           1 // QList<QByteArray >
-#define SBK_QTUITOOLS_QLIST_QVARIANT_IDX                             2 // QList<QVariant >
-#define SBK_QTUITOOLS_QLIST_QSTRING_IDX                              3 // QList<QString >
-#define SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                      4 // QMap<QString,QVariant >
-#define SBK_QtUiTools_CONVERTERS_IDX_COUNT                           5
-
+enum : int {
+    SBK_QTUITOOLS_QLIST_QOBJECTPTR_IDX                       = 0, // const QList<QObject* > &
+    SBK_QTUITOOLS_QLIST_QBYTEARRAY_IDX                       = 1, // QList<QByteArray >
+    SBK_QTUITOOLS_QLIST_QVARIANT_IDX                         = 2, // QList<QVariant >
+    SBK_QTUITOOLS_QLIST_QSTRING_IDX                          = 3, // QList<QString >
+    SBK_QTUITOOLS_QMAP_QSTRING_QVARIANT_IDX                  = 4, // QMap<QString,QVariant >
+    SBK_QtUiTools_CONVERTERS_IDX_COUNT                       = 5
+};
 // Macros for type check
 
 namespace Shiboken
