@@ -46,12 +46,6 @@
 
 #include <sbkpython.h>
 #include <sbkconverter.h>
-#include <sbkenum.h>
-#include <basewrapper.h>
-#include <bindingmanager.h>
-#include <memory>
-
-#include <pysidesignal.h>
 // Module Includes
 #include <pyside2_qtcore_python.h>
 
@@ -60,37 +54,42 @@
 // Conversion Includes - Primitive Types
 #include <qabstractitemmodel.h>
 #include <QString>
-#include <signalmanager.h>
 #include <QStringList>
+#include <signalmanager.h>
 
 // Conversion Includes - Container Types
-#include <QStack>
+#include <pysideqflags.h>
+#include <QLinkedList>
 #include <QList>
 #include <QMap>
-#include <pysideqflags.h>
+#include <QMultiMap>
 #include <QPair>
 #include <QQueue>
-#include <QMultiMap>
 #include <QSet>
-#include <QLinkedList>
+#include <QStack>
 #include <QVector>
 
 // Type indices
-#define SBK_QTWEBENGINE_IDX                                          0
-#define SBK_QtWebEngine_IDX_COUNT                                    1
-
+enum : int {
+    SBK_QTWEBENGINE_IDX                                      = 0,
+    SBK_QtWebEngine_IDX_COUNT                                = 1
+};
 // This variable stores all Python types exported by this module.
 extern PyTypeObject** SbkPySide2_QtWebEngineTypes;
 
+// This variable stores the Python module object exported by this module.
+extern PyObject* SbkPySide2_QtWebEngineModuleObject;
+
 // This variable stores all type converters exported by this module.
 extern SbkConverter** SbkPySide2_QtWebEngineTypeConverters;
 
 // Converter indices
-#define SBK_QTWEBENGINE_QLIST_QVARIANT_IDX                           0 // QList<QVariant >
-#define SBK_QTWEBENGINE_QLIST_QSTRING_IDX                            1 // QList<QString >
-#define SBK_QTWEBENGINE_QMAP_QSTRING_QVARIANT_IDX                    2 // QMap<QString,QVariant >
-#define SBK_QtWebEngine_CONVERTERS_IDX_COUNT                         3
-
+enum : int {
+    SBK_QTWEBENGINE_QLIST_QVARIANT_IDX                       = 0, // QList<QVariant >
+    SBK_QTWEBENGINE_QLIST_QSTRING_IDX                        = 1, // QList<QString >
+    SBK_QTWEBENGINE_QMAP_QSTRING_QVARIANT_IDX                = 2, // QMap<QString,QVariant >
+    SBK_QtWebEngine_CONVERTERS_IDX_COUNT                     = 3
+};
 // Macros for type check
 
 namespace Shiboken
