@@ -1,24 +1,26 @@
 __all__ = list("Qt" + body for body in
     "Core;Gui;Widgets;PrintSupport;Sql;Network;Test;Concurrent;X11Extras;Xml;XmlPatterns;Help;Multimedia;MultimediaWidgets;OpenGL;Positioning;Location;Qml;Quick;QuickWidgets;Scxml;Script;ScriptTools;Sensors;TextToSpeech;Charts;Svg;DataVisualization;UiTools;WebChannel;WebEngineCore;WebEngine;WebEngineWidgets;WebSockets;3DCore;3DRender;3DInput;3DLogic;3DAnimation;3DExtras"
     .split(";"))
-__version__ = "5.11.2"
-__version_info__ = (5, 11, 2, "", "")
-
-__build_date__ = '2018-09-22T00:12:31+00:00'
-
-
-
-
-# Timestamp used for snapshot build, which is part of snapshot package version.
-__setup_py_package_timestamp__ = ''
+__version__ = "5.12.0"
+__version_info__ = (5, 12, 0, "", "")
 
 def _setupQtDirectories():
     import sys
     import os
 
+    # On Windows we need to explicitly import the shiboken2 module so
+    # that the libshiboken.dll dependency is loaded by the time a
+    # Qt module is imported. Otherwise due to PATH not containing
+    # the shiboken2 module path, the Qt module import would fail
+    # due to the missing libshiboken dll.
+    # We need to do the same on Linux and macOS, because we do not
+    # embed rpaths into the PySide2 libraries that would point to
+    # the libshiboken library location. Importing the module
+    # loads the libraries into the process memory beforehand, and
+    # thus takes care of it for us.
+    import shiboken2
+
     pyside_package_dir =  os.path.abspath(os.path.dirname(__file__))
-    # Used by signature module.
-    os.environ["PYSIDE_PACKAGE_DIR"] = pyside_package_dir
 
     if sys.platform == 'win32':
         # PATH has to contain the package directory, otherwise plugins
